<?php
// $Id$

/**
 * @file
 * Feeds parser for Evanced Calendar.
 */

class SPLTESTEvancedCalendarParser extends FeedsParser {

  /**
   * Add additional mapping sources.
   */
  public function getMappingSources() {
    $sources = array(
      'title' => array(
        'name' => t('Title'),
        'description' => t('Event Title'),
      ),
      'date' => array(
        'name' => t('Date'),
        'description' => t('Date of the event'),
      ),
      'time' => array(
        'name' => t('Time'),
        'description' => t('The time the event starts'),
      ),
      'description' => array(
        'name' => t('Description'),
        'description' => t('Event description'),
      ),
      'location' => array(
        'name' => t('Location'),
        'description' => t('Location of the event'),
      ),
      'library' => array(
        'name' => t('Library'),
        'description' => t('Library name associated with the event'),
      ),
      'link' => array(
        'name' => t('Link'),
        'description' => t('Link to the Event Information and Registration Page, if registration is required'),
      ),
      'date1' => array(
        'name' => t('Date1'),
        'description' => t('Date in yyyy/mm/dd (year / month / day) format'),
      ),
      'date2' => array(
        'name' => t('Date2'),
        'description' => t('Value that can be used for sorting (yyyymmddhhmm[event title]) (year month day hour minutes format)'),
      ),
      'length' => array(
        'name' => t('Length'),
        'description' => t('Event length'),
      ),
      'status' => array(
        'name' => t('Status'),
        'description' => t('Event status'),
      ),
      'endtime' => array(
        'name' => t('Endtime'),
        'description' => t('The time the event ends'),
      ),
      'prieventtype' => array(
        'name' => t('Primary Type'),
        'description' => t('Primary Event Type'),
      ),
      'eventtypes' => array(
        'name' => t('Event Types'),
        'description' => t('Alternate Event Types'),
      ),
      'agegroups' => array(
        'name' => t('Age Groups'),
        'description' => t('Age Groups'),
      ),
      'otherinfo' => array(
        'name' => t('Other Info'),
        'description' => t('Other information'),
      ),
      'presenter' => array(
        'name' => t('Presenter'),
        'description' => t('The name of the Presenter'),
      ),
      'signup' => array(
        'name' => t('Sign up value'),
        'description' => t('0 - no sign up, 1 - Staff and Patron, 3 - Staff only'),
      ),
      'signupstarts' => array(
        'name' => t('Sign up starts'),
        'description' => t('Sign up starts'),
      ),
      'signupends' => array(
        'name' => t('Sign up ends'),
        'description' => t('Sign up ends'),
      ),
      'contactname' => array(
        'name' => t('Contact Name'),
        'description' => t('Contact name'),
      ),
      'contactphone' => array(
        'name' => t('Contact Phone'),
        'description' => t('Contact phone number'),
      ),
      'contactemail' => array(
        'name' => t('Contact E-mail'),
        'description' => t('Contact email address'),
      ),
      'linktext' => array(
        'name' => t('Link Text'),
        'description' => t('Link text'),
      ),
      'linkaddress' => array(
        'name' => t('Link Address'),
        'description' => t('Link web address'),
      ),
      'imagepath' => array(
        'name' => t('Image Path'),
        'description' => t('Image path'),
      ),
      'imagetext' => array(
        'name' => t('Image Text'),
        'description' => t('Image alternate text'),
      ),
      'imageheight' => array(
        'name' => t('Image Height'),
        'description' => t('Image height'),
      ),
      'imagewidth' => array(
        'name' => t('Image Width'),
        'description' => t('Image width'),
      ),
      // lastupdated -- Not in the documentation.
      'lastupdated' => array(
        'name' => t('Last Updated'),
        'description' => t('Timestamp of last update.'),
      ),
      'extratag' => array(
        'name' => t('Extra tag'),
        'description' => t('An extra tag that can be altered programmatically for sorting or flagging certain events'),
      ),
      'testone' => array(
        'name' => t('TESTONE'),
        'description' => t('Bdragon -- debugging code'),
      ),
      'testtwo' => array(
        'name' => t('TESTTWO'),
        'description' => t('Bdragon -- debugging code'),
      ),

      'start_timestamp' => array(
        'name' => t('Start time (unix timestamp)'),
        'description' => t('The start timestamp.'),
      ),
      'end_timestamp' => array(
        'name' => t('End time (unix timestamp)'),
        'description' => t('The end timestamp.'),
      ),
      'signup_start_timestamp' => array(
        'name' => t('Signup start time (unix timestamp)'),
        'description' => t('The signup start timestamp.'),
      ),
      'signup_end_timestamp' => array(
        'name' => t('Signup end time (unix timestamp)'),
        'description' => t('The signup end timestamp.'),
      ),

    );
//    return parent::getMappingSources() + $sources;
    return $sources;
  }

  public function parse(FeedsFetcherResult $fetcherResult, FeedsSource $source) {
    if ($fetcherResult->type == 'text/filepath') {
      $string = file_get_contents($fetcherResult->value);
    }
    else {
      $string = $fetcherResult->value;
    }

    $items = array();
    $tags = array_keys(self::getMappingSources());
//watchdog('DEBUG', print_r($tags, TRUE));

    foreach (array('testone') as $omit) {
      foreach ($tags as $k => $v) {
        if ($v == $omit) {
          unset($tags[$k]);
        }
      }
    }
//watchdog('DEBUG', print_r($tags, TRUE));

    foreach (qp($string, 'item') as $item) {
      $i = array();
      foreach ($tags as $key) {
        $work = $item->branch();
//watchdog('TEST', $key);
        $i[$key] = $work->find($key)->text();
      }
      $work = $item->branch();
      $work2 = $item->branch();
      if (strtolower($i['time']) == 'all day') {
        $i['time'] = '';
      }
      if (strtolower($i['endtime']) == 'all day') {
        $i['endtime'] = '';
      }
//      $i['testone'] = strtotime($work->find('date')->text() .' '. $work2->find('time')->text());
      //$i['testone'] = date_convert($i['date'] .' '. $i['time'], '%DATE_DATETIME', DATE_UNIX, 'America/Chicago');
      $i['start_timestamp'] = date_create($i['date'] .' '. $i['time'], new DateTimeZone('America/Chicago'))->format(DATE_FORMAT_UNIX);
      $i['end_timestamp'] = date_create($i['date'] .' '. $i['endtime'], new DateTimeZone('America/Chicago'))->format(DATE_FORMAT_UNIX);
      $i['signup_start_timestamp'] = 0;
      $i['sitnup_end_timestamp'] = 0;
      if (!empty($i['signupstarts'])) {
        $i['signup_start_timestamp'] = date_create($i['signupstarts'], new DateTimeZone('America/Chicago'))->format(DATE_FORMAT_UNIX);
      }
      if (!empty($i['signupends'])) {
        $i['signup_end_timestamp'] = date_create($i['signupends'], new DateTimeZone('America/Chicago'))->format(DATE_FORMAT_UNIX);
      }
      //print_r(date_convert('Tuesday, December 08, 2009 7:00 PM', DATE_DATETIME, DATE_UNIX, 'America/Chicago'));
//      var_export(date_make_date(strptime('Tuesday, December 08, 2009 7:00 PM', '%A, %B %d, %Y %l:%M %p'), 'America/Chicago'));
//      var_export(strptime('Tuesday, December 08, 2009 7:00 PM', '%A, %B %d, %Y %l:%M %p'));
//      var_export(strftime(DATE_ISO8601, strptime('Tuesday, December 08, 2009 7:00 PM', '%A, %B %d, %Y %l:%M %p')));
//      var_export(date_make_date(date_parse('Tuesday, December 08, 2009 7:00 PM'), 'America/Chicago'));
      $items[] = $i;
    }

watchdog('TEST', print_r($items, TRUE));

    return new FeedsParserResult(array('items' => $items), 'syndication');
  }
}
